rainbowlog.ansi API documentation

# Module `rainbowlog.ansi`

## Classes

`class Color (value, names=None, *, module=None, qualname=None, type=None, start=1)`

  An enumeration.

  ### Ancestors

  - enum.Enum

  ### Class variables

  `var BLACK`
  `var BLUE`
  `var CYAN`
  `var GREEN`
  `var MAGENTA`
  `var RED`
  `var WHITE`
  `var YELLOW`
`class Format (foreground: Color = None, background: Color = None, style: Union[Style, Iterable[Style]] = ())`

  This class represents a format for a log message. It can be used to specify the foreground and background colors and other ANSI styles.

  ## Args

  `foreground`
    The foreground color.
  `background`
    The background color.
  `style`
    The style. This can be a single style or several styles.

  ### Ancestors

  - collections.abc.Mapping
  - collections.abc.Collection
  - collections.abc.Sized
  - collections.abc.Iterable
  - collections.abc.Container
  - typing.Generic

  ### Methods

  `def keys(self) ‑> KeysView[str]`

    D.keys() -> a set-like object providing a view on D's keys

`class Style (value, names=None, *, module=None, qualname=None, type=None, start=1)`

  An enumeration.

  ### Ancestors

  - enum.Enum

  ### Class variables

  `var BLINK`
  `var BLINK2`
  `var BOLD`
  `var CONCEALED`
  `var CROSSED`
  `var FAINT`
  `var ITALIC`
  `var NEGATIVE`
  `var NONE`
  `var UNDERLINE`